@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from .jinja.environment import Environment
+from .jinja.nodeenvironment import NodeEnvironment
 
 from .basenodes.mkblock import MkBlock
 from .basenodes.mkhtmlblock import MkHtmlBlock
@@ -30,7 +31,9 @@ from .basenodes.mklist import MkList
 from .basenodes.mkdiagram import MkDiagram
 from .basenodes.mktable import MkTable
 from .basenodes.mkhtmltable import MkHtmlTable
-from .basenodes.mktabcontainer import MkTabbedBlocks, MkTabbed
+from .basenodes.mktabcontainer import MkTabContainer
+from .basenodes.mktabbedblocks import MkTabbedBlocks
+from .basenodes.mktabbed import MkTabbed
 from .basenodes.mksnippet import MkSnippet
 from .basenodes.mkcritic import MkCritic
 from .basenodes.mkannotations import MkAnnotations
@@ -78,6 +81,7 @@ from .templatenodes.mkmoduletable import MkModuleTable
 from .templatenodes.mkpluginflow import MkPluginFlow
 from .templatenodes.mkargparsehelp import MkArgParseHelp
 from .templatenodes.mkjinjatemplate import MkJinjaTemplate
+from .templatenodes.mkjinjatext import MkJinjaText
 from .templatenodes.mkpydeps import MkPyDeps
 from .templatenodes.mkpipdeptree import MkPipDepTree
 
@@ -92,6 +96,7 @@ from .theme.materialtheme import MaterialTheme
 
 __all__ = [
     "Environment",
+    "NodeEnvironment",
     "MkNode",
     "MkDefaultWebsite",
     "MkBlockQuote",
@@ -133,6 +138,7 @@ __all__ = [
     "MkAnnotations",
     "MkFootNotes",
     "MkDoc",
+    "MkTabContainer",
     "MkTabbedBlocks",
     "MkTabbed",
     "MkSnippet",
@@ -170,6 +176,7 @@ __all__ = [
     "MkTaskList",
     "MkTimeline",
     "MkJinjaTemplate",
+    "MkJinjaText",
     "MkPyDeps",
     "MkPipDepTree",
     "Router",
@@ -177,4 +184,4 @@ __all__ = [
     "MaterialTheme",
 ]
 
-__version__ = "0.44.3"
+__version__ = "0.46.0"
