@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import contextlib
+import dataclasses
 import functools
 import importlib
 import os
@@ -8,20 +9,27 @@ import pathlib
 import re
 import types
 
-from typing import TYPE_CHECKING, Self
+from typing import TYPE_CHECKING
 
 from mknodes.data import commitconventions, installmethods, taskrunners, tools
 from mknodes.info import (
     contexts,
     # githubinfo,
-    gitrepository,
     grifferegistry,
     license,
     mkdocsconfigfile,
     packageregistry,
     pyproject,
+    reporegistry,
+)
+from mknodes.utils import (
+    icons,
+    log,
+    packagehelpers,
+    pathhelpers,
+    reprhelpers,
+    yamlhelpers,
 )
-from mknodes.utils import log, packagehelpers, pathhelpers, reprhelpers, yamlhelpers
 
 
 if TYPE_CHECKING:
@@ -31,24 +39,9 @@ if TYPE_CHECKING:
 
     from mknodes.info import packageinfo
 
-
 logger = log.get_logger(__name__)
 
 
-SOCIALS = {
-    "gitter.im": "fontawesome/brands/gitter",
-    "matrix.to": "fontawesome/brands/gitter",
-    "twitter.com": "fontawesome/brands/twitter",
-    "docker.com": "fontawesome/brands/docker",
-    "fosstodon.org": "fontawesome/brands/mastodon",
-    "discord.gg": "fontawesome/brands/discord",
-    "discord.com": "fontawesome/brands/discord",
-    "linkedin.com": "fontawesome/brands/linkedin",
-    "dev.to": "fontawesome/brands/dev",
-    "medium.to": "fontawesome/brands/medium",
-}
-
-
 GITHUB_REGEX = re.compile(
     r"(?:http?:\/\/|https?:\/\/)?"
     r"(?:www\.)?"
@@ -60,6 +53,21 @@ GITHUB_REGEX = re.compile(
 )
 
 
+@dataclasses.dataclass
+class PackageExtra:
+    """A class describing a package extra, used to define additional dependencies."""
+
+    name: str
+    """Name of the extra."""
+    packages: list[str] = dataclasses.field(default_factory=list)
+    """List of packages which are part of the extra."""
+    description: str = ""
+    """Optional description for the extra.
+
+    Must be defined in pyproject mknodes section.
+    """
+
+
 class FolderInfo:
     """Aggregates information about a working dir."""
 
@@ -69,10 +77,10 @@ class FolderInfo:
         Arguments:
             path: Path to the repo.
         """
-        self.path = pathlib.Path(path or ".")
-        self.pyproject = pyproject.PyProject(self.path)
         # packagehelpers.install_or_import(mod_name)
-        self.git = gitrepository.GitRepository(self.path)
+        self.git = reporegistry.get_repo(path or ".")
+        self.path = pathlib.Path(self.git.working_dir)
+        self.pyproject = pyproject.PyProject(self.path)
         self.mkdocs_config = mkdocsconfigfile.MkDocsConfigFile()
         if (mk_path := self.path / "mkdocs.yml").exists():
             with contextlib.suppress(yamlhelpers.YAMLError):
@@ -102,37 +110,23 @@ class FolderInfo:
     def __repr__(self):
         return reprhelpers.get_repr(self, path=self.path)
 
-    @classmethod
-    def clone_from(
-        cls,
-        url: str,
-        # path: str | os.PathLike,
-        depth: int = 100,
-    ) -> Self:
-        """Create a FolderInfo from a remote repository url.
-
-        Arguments:
-            url: Url of the repository
-            depth: Amount of commits to clone. Useful for changelog generation.
-        """
-        import tempfile
-
-        import git
-
-        directory = tempfile.TemporaryDirectory(prefix="mknodes_repo_")
-        logger.info("Created temporary directory %s", directory.name)
-        logger.info("Cloning %s with depth %s", url, depth)
-        repo = git.Repo.clone_from(url, directory.name, depth=depth)
-        logger.info("Finished cloning.")
-        kls = cls(repo.working_dir)
-        kls._temp_directory = directory
-        return kls
-
     @functools.cached_property
     def info(self) -> packageinfo.PackageInfo:
         """Return a PackageInfo object for given distribution."""
         return packageregistry.get_info(self.pyproject.name or self.git.repo_name)
 
+    @functools.cached_property
+    def extras(self) -> dict[str, PackageExtra]:
+        """Return a dict containing extras and the packages {extra: [package_1, ...]}."""
+        dct = {}
+        for k, v in self.info.extras.items():
+            dct[k] = PackageExtra(
+                k,
+                packages=v,
+                description=self.pyproject.extras_descriptions.get(k, ""),
+            )
+        return dct
+
     @functools.cached_property
     def repository_url(self) -> str:
         """Return url of the repository by querying multiple sources.
@@ -178,8 +172,15 @@ class FolderInfo:
 
     @functools.cached_property
     def package_repos(self) -> list[installmethods.InstallMethodStr]:
-        """Return package repositories this distribution is hosted on."""
-        return self.pyproject.package_repos
+        """Return a list of package repositories the package is available on."""
+        repos = self.pyproject.package_repos or ["pip"]
+        if (
+            "pip" in repos
+            and "pipx" not in repos
+            and "console_scripts" in self.info.entry_points
+        ):
+            repos.append("pipx")
+        return repos
 
     @functools.cached_property
     def commit_types(self) -> list[commitconventions.CommitTypeStr]:
@@ -230,15 +231,16 @@ class FolderInfo:
         result = []
         if url := self.repository_url:
             result.append(
-                dict(icon="fontawesome/brands/github", link=url),
+                dict(icon="fa-brands:github", link=url),
             )
         for link in self.info.urls.values():
-            result.extend(
-                dict(icon=v, link=link) for k, v in SOCIALS.items() if k in link
-            )
+            if "github" in link or "pypi.org" in link:
+                continue
+            if icon := icons.icon_for_url(link):
+                result.append(dict(icon=icon, link=link))
         result.append(
             dict(
-                icon="fontawesome/brands/python",
+                icon="fa-brands:python",
                 link=f"https://pypi.org/project/{self.module.__name__}/",
             ),
         )
@@ -279,10 +281,11 @@ class FolderInfo:
             required_python_version=self.info.required_python_version,
             required_packages=self.info.required_packages,
             required_package_names=self.info.required_package_names,
-            extras=self.info.extras,
+            extras=self.extras,
             tools=self.tools,
             entry_points=self.info.entry_points,
             cli=self.info.cli,
+            cli_info=self.info.cli_info,
             mkdocs_config=self.mkdocs_config,
             pyproject_file=self.pyproject,
             social_info=self.social_info,
@@ -296,13 +299,12 @@ class FolderInfo:
             configured_build_systems=self.pyproject.configured_build_systems,
             tool_section=self.pyproject.tool,
             commit_types=self.pyproject.allowed_commit_types,
-            extras_descriptions=self.pyproject.extras_descriptions,
             package_repos=self.pyproject.package_repos,
             line_length=self.pyproject.line_length,
         )
 
 
 if __name__ == "__main__":
-    info = FolderInfo()
+    info = FolderInfo("https://github.com/mkdocs/mkdocs.git")
+    print(info.context)
     log.basic()
-    logger.warning(info.griffe_module)
