@@ -1,9 +1,10 @@
 from __future__ import annotations
 
+import collections
 import contextlib
 import functools
 
-from mknodes.utils import log, packagehelpers, reprhelpers
+from mknodes.utils import clihelpers, log, packagehelpers, reprhelpers
 
 
 logger = log.get_logger(__name__)
@@ -60,26 +61,15 @@ class PackageInfo:
         """Get name of the license."""
         if license_name := self.metadata.get("License-Expression", "").strip():
             return license_name
-        return next(
-            (
-                value.rsplit("::", 1)[1].strip()
-                for header, value in self.metadata.items()
-                if header == "Classifier" and value.startswith("License ::")
-            ),
-            None,
-        )
+        if license_names := self.classifier_map.get("License"):
+            return license_names[0].split(" :: ")[-1]
+        return None
 
     @functools.cached_property
     def repository_url(self) -> str | None:
         """Return repository URL from metadata."""
-        return next(
-            (
-                self.urls[tag]
-                for tag in ["Source", "Repository", "Source Code"]
-                if tag in self.urls
-            ),
-            None,
-        )
+        tags = ["Source", "Repository", "Source Code"]
+        return next((self.urls[tag] for tag in tags if tag in self.urls), None)
 
     @functools.cached_property
     def homepage(self) -> str | None:
@@ -98,7 +88,7 @@ class PackageInfo:
         return self.metadata.get("Keywords", "").split(",")
 
     @functools.cached_property
-    def classifier_map(self) -> dict[str, list[str]]:
+    def classifier_map(self) -> collections.defaultdict[str, list[str]]:
         """Return a dict containing the classifier categories and values from metadata.
 
         {category_1: [classifier_1, ...],
@@ -106,15 +96,12 @@ class PackageInfo:
          ...
          }
         """
-        classifiers: dict[str, list[str]] = {}
+        classies: collections.defaultdict[str, list[str]] = collections.defaultdict(list)
         for k, v in self.metadata.items():
             if k == "Classifier":
                 category, value = v.split(" :: ", 1)
-                if category in classifiers:
-                    classifiers[category].append(value)
-                else:
-                    classifiers[category] = [value]
-        return classifiers
+                classies[category].append(value.strip())
+        return classies
 
     @functools.cached_property
     def required_package_names(self) -> list[str]:
@@ -151,15 +138,12 @@ class PackageInfo:
         return authors
 
     @functools.cached_property
-    def extras(self) -> dict[str, list[str]]:
+    def extras(self) -> collections.defaultdict[str, list[str]]:
         """Return a dict containing extras and the packages {extra: [package_1, ...]}."""
-        extras: dict[str, list[str]] = {}
+        extras: collections.defaultdict[str, list[str]] = collections.defaultdict(list)
         for dep in self._required_deps:
             for extra in dep.extras:
-                if extra in extras:
-                    extras[extra].append(dep.name)
-                else:
-                    extras[extra] = [dep.name]
+                extras[extra].append(dep.name)
         return extras
 
     @functools.cached_property
@@ -196,8 +180,20 @@ class PackageInfo:
         eps = self.entry_points.get("console_scripts")
         if not eps:
             return None
-        ep = eps[0]
-        return "typer" if ep.load().__class__.__qualname__ == "Typer" else "click"
+        ep = eps[0].load()
+        return "typer" if ep.__class__.__qualname__ == "Typer" else "click"
+
+    @functools.cached_property
+    def cli_info(self) -> clihelpers.CommandInfo | None:
+        """Return a CLI info object containing infos about all CLI commands / options."""
+        eps = self.entry_points.get("console_scripts")
+        if not eps:
+            return None
+        ep = eps[0].load()
+        qual_name = ep.__class__.__module__.lower()
+        if qual_name.startswith(("typer", "click")):
+            return clihelpers.get_typer_info(ep)
+        return None
 
     @functools.cached_property
     def entry_points(self) -> dict[str, list[packagehelpers.EntryPoint]]:
@@ -207,4 +203,4 @@ class PackageInfo:
 
 if __name__ == "__main__":
     info = PackageInfo("mknodes")
-    print(info.cli)
+    print(info.license_name)
