@@ -84,13 +84,20 @@ class PyProject(tomlfile.TomlFile):
     @property
     def package_repos(self) -> list[installmethods.InstallMethodStr]:
         """Return a list of package repositories the package is available on."""
-        return self.mknodes_section.get("package-repositories", ["pip"])
+        return self.mknodes_section.get("package-repositories", [])
 
     @property
     def docstring_style(self) -> str | None:
         """Return the style used for docstring."""
+        if convention := self.tool["pydocstyle"].get("convention"):
+            return convention
         return self.mknodes_section.get("docstring-style")
 
+    @property
+    def argparser_path(self) -> str | None:
+        """Return path to an ArgumentParser, used for documenting the CLI."""
+        return self.mknodes_section.get("argparser-path")
+
     @property
     def line_length(self) -> int | None:
         # sourcery skip: assign-if-exp, reintroduce-else
