@@ -11,14 +11,7 @@ from urllib import parse
 from mknodes.basenodes import mkcontainer, mkfootnotes, mknode, processors
 from mknodes.data import datatypes
 from mknodes.pages import metadata, pagetemplate
-from mknodes.utils import (
-    downloadhelpers,
-    helpers,
-    inspecthelpers,
-    log,
-    reprhelpers,
-    resources,
-)
+from mknodes.utils import helpers, inspecthelpers, log, pathhelpers, reprhelpers
 
 
 logger = log.get_logger(__name__)
@@ -106,10 +99,6 @@ class MkPage(mkcontainer.MkContainer):
         kwargs = {k: v for k, v in self.metadata.items() if v is not None}
         return reprhelpers.get_repr(self, path=str(self.path), **kwargs)
 
-    def get_node_resources(self) -> resources.Resources:
-        templates = [self.template] if self.template else []
-        return resources.Resources(templates=templates)
-
     def is_index(self) -> bool:
         """Returns True if the page is the index page for the parent Nav."""
         return bool(self._is_index)
@@ -141,6 +130,11 @@ class MkPage(mkcontainer.MkContainer):
     def path(self, value: str | None):
         self._path = value
 
+    @property
+    def edit_url(self) -> str:
+        base_url = parse.urljoin(self.ctx.metadata.repository_url, "edit/main/")
+        return parse.urljoin(base_url, self._edit_path)
+
     @property
     def resolved_file_path(self) -> str:
         """Returns the resulting section/subsection/../filename.xyz path."""
@@ -150,7 +144,7 @@ class MkPage(mkcontainer.MkContainer):
         return path.lstrip("/")
 
     @property
-    def status(self) -> datatypes.PageStatusStr | None:
+    def status(self) -> datatypes.PageStatusStr | str | None:
         """Return page status from metadata."""
         return self.metadata.status
 
@@ -219,16 +213,15 @@ class MkPage(mkcontainer.MkContainer):
         Parses and reads header metadata.
 
         Arguments:
-            path: Path to load file from
+            path: Path to load file from, either a local path or a fsspec protocol path.
             title: Optional title to use
                    If None, title will be infered from metadata or filename
             parent: Optional parent for new page
             kwargs: Additional metadata for MkPage. Will override parsed metadata.
         """
-        if helpers.is_url(url := str(path)):
-            file_content = downloadhelpers.download(url).decode()
-            split = parse.urlsplit(url)
-            path = f"{title}.md" if title else pathlib.Path(split.path).name
+        if "://" in (url := str(path)):
+            file_content = pathhelpers.load_file_cached(url)
+            path = f"{title}.md" if title else pathlib.Path(parse.urlsplit(url).path).name
             path = pathlib.Path(path)
         else:
             path = pathlib.Path(path)
