@@ -2,8 +2,9 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
+from mknodes.mdlib import mdconverter
 from mknodes.pages import templateblocks
-from mknodes.utils import mdconverter, reprhelpers
+from mknodes.utils import reprhelpers
 
 
 if TYPE_CHECKING:
@@ -52,7 +53,7 @@ class PageTemplate:
         self.announce = templateblocks.HtmlBlock("announce", parent=parent)
 
     def __bool__(self):
-        return any(self.blocks)
+        return any(self.blocks)  # or self.extends
 
     def __hash__(self):
         return hash(self.build_html())
@@ -94,7 +95,7 @@ class PageTemplate:
         import mknodes as mk
 
         if isinstance(value, mk.MkNode):
-            value.associated_project = self.parent.associated_project
+            value._ctx = self.parent.ctx
         self.announce.content = value
 
     @property
