@@ -5,7 +5,8 @@ import os
 from typing import TYPE_CHECKING, Literal
 
 from mknodes.basenodes import mknode
-from mknodes.utils import css as css_, helpers, mdconverter, resources
+from mknodes.mdlib import mdconverter
+from mknodes.utils import css as css_, helpers, resources
 
 
 if TYPE_CHECKING:
@@ -147,11 +148,9 @@ class TitleBlock(BaseBlock):
         return f"<title>{self.content}</title>"
 
 
-class LibsBlock(BaseBlock):
+class BaseJSBlock(BaseBlock):
     """Block for additional libraries."""
 
-    block_id = "libs"
-
     def __init__(
         self,
         scripts: list[resources.JSFile] | None = None,
@@ -185,18 +184,24 @@ class LibsBlock(BaseBlock):
         return f"{SUPER_TEXT}\n{scripts}" if self.include_super else scripts
 
 
+class LibsBlock(BaseJSBlock):
+    """Block for additional libraries."""
+
+    block_id = "libs"
+
+
+class ScriptsBlock(BaseJSBlock):
+    """Block for JavaScripts at end of BODY."""
+
+    block_id = "scripts"
+
+
 class AnalyticsBlock(Block):
     """Block for analytics-tags in HEAD."""
 
     block_id = "analytics"
 
 
-class ScriptsBlock(Block):
-    """Block for JavaScripts at end of BODY."""
-
-    block_id = "scripts"
-
-
 class SiteMetaBlock(Block):
     """Block for meta tags in HEAD."""
 
