@@ -9,11 +9,11 @@ import pathlib
 from typing import Any, Generic, TypeVar
 
 from mknodes import paths
-from mknodes.info import contexts, folderinfo, linkprovider, packageregistry
+from mknodes.info import contexts, folderinfo, linkprovider, reporegistry
 from mknodes.jinja import environment
 from mknodes.navs import mknav
 from mknodes.theme import theme as theme_
-from mknodes.utils import classhelpers, helpers, jinjahelpers, log, reprhelpers
+from mknodes.utils import classhelpers, log, reprhelpers
 
 
 logger = log.get_logger(__name__)
@@ -34,6 +34,7 @@ class Project(Generic[T]):
         base_url: str = "",
         use_directory_urls: bool = True,
         clone_depth: int = 100,
+        jinja_extensions: list[str] | None = None,
     ):
         """The main project to create a website.
 
@@ -45,29 +46,20 @@ class Project(Generic[T]):
             base_url: Base url of the website
             use_directory_urls: Whether urls are in directory-style
             clone_depth: Amount of commits to clone in case repository is remote.
+            jinja_extensions: Optional additional jinja extensions to load.
         """
         self.linkprovider = linkprovider.LinkProvider(
             base_url=base_url,
             use_directory_urls=use_directory_urls,
             include_stdlib=True,
         )
-        self.env = environment.Environment(undefined="strict", load_templates=True)
-        self.env.filters["get_link"] = self.linkprovider.get_link
-        self.env.filters["get_url"] = self.linkprovider.get_url
-        jinjahelpers.set_markdown_exec_namespace(self.env.globals)
+        self._root: mknav.MkNav | None = None
+        self.build_fn = classhelpers.to_callable(build_fn)
+        self.build_kwargs = build_kwargs or {}
+        self.env = environment.Environment(load_templates=True)
         self.theme: T = theme
-        self.theme.associated_project = self
-        match repo:
-            case folderinfo.FolderInfo():
-                self.folderinfo = repo
-            case _ if helpers.is_url(str(repo)):
-                self.folderinfo = folderinfo.FolderInfo.clone_from(
-                    str(repo),
-                    depth=clone_depth,
-                )
-            case _:
-                self.folderinfo = folderinfo.FolderInfo(repo)
-
+        git_repo = reporegistry.get_repo(str(repo or "."), clone_depth=clone_depth)
+        self.folderinfo = folderinfo.FolderInfo(git_repo.working_dir)
         self.context = contexts.ProjectContext(
             metadata=self.folderinfo.context,
             git=self.folderinfo.git.context,
@@ -76,13 +68,13 @@ class Project(Generic[T]):
             links=self.linkprovider,
             env=self.env,
         )
+        self.theme.ctx = self.context
 
-        self.env.globals |= self.context.as_dict()
-        self._root: mknav.MkNav | None = None
-        self.build_fn = classhelpers.to_callable(build_fn)
-        self.build_kwargs = build_kwargs or {}
-
-    def build(self):
+    def build(
+        self,
+        build_fn: str | Callable = paths.DEFAULT_BUILD_FN,
+        build_kwargs: dict[str, Any] | None = None,
+    ):
         logger.debug("Building page...")
         self.build_fn(project=self, **self.build_kwargs)
         logger.debug("Finished building page.")
@@ -124,7 +116,7 @@ class Project(Generic[T]):
     def set_root(self, nav: mknav.MkNav):
         """Set the root MkNav."""
         self._root = nav
-        nav.associated_project = self
+        nav._ctx = self.context
 
     def get_root(self, **kwargs: Any) -> mknav.MkNav:
         """Return the root MkNav.
@@ -135,18 +127,9 @@ class Project(Generic[T]):
         Arguments:
             kwargs: Keyword arguments passed to MkNav constructor.
         """
-        self._root = mknav.MkNav(project=self, **kwargs)
+        self._root = mknav.MkNav(context=self.context, **kwargs)
         return self._root
 
-    def populate_linkprovider(self):
-        invs = self.folderinfo.mkdocs_config.get_inventory_infos()
-        mk_urls = {i["url"]: i.get("base_url") for i in invs if "url" in i}
-        for url, base_url in mk_urls.items():
-            self.linkprovider.add_inv_file(url, base_url=base_url)
-        for url in packageregistry.registry.inventory_urls:
-            if url not in mk_urls:
-                self.linkprovider.add_inv_file(url)
-
 
 if __name__ == "__main__":
     import mknodes as mk
