@@ -20,15 +20,15 @@ class Theme:
 
     def __init__(
         self,
-        theme_name: str,
+        name: str,
         *,
         data: dict[str, Any] | None = None,
-        project: project.Project | None = None,
+        context: project.Project | None = None,
         template_registry: templateregistry.TemplateRegistry | None = None,
     ):
-        self.associated_project = project
+        self.ctx = context or contexts.ProjectContext()
 
-        self.theme_name = theme_name
+        self.name = name
         self.data = data or {}
         self.features = self.data.get("features")
 
@@ -36,6 +36,8 @@ class Theme:
         self.main_template = self.templates["main.html"]
         self.error_page = self.templates["404.html"]
 
+        self.alternating_table_colors = False
+
         self.admonitions: list[admonition.AdmonitionType] = []
         self.add_admonition_type(
             name="theme",
@@ -47,7 +49,7 @@ class Theme:
         )
 
     def __repr__(self):
-        return reprhelpers.get_repr(self, theme_name=self.theme_name)
+        return reprhelpers.get_repr(self, name=self.name)
 
     def add_admonition_type(
         self,
@@ -88,17 +90,16 @@ class Theme:
         Usually, the resources consist of static templates and CSS.
         """
         req: list[resources.CSSFile | resources.CSSText] = []
-        if self.css_template and (proj := self.associated_project):
-            tmpl_ctx = self.get_template_context()
-            css_text = proj.context.env.render_template(
+        if self.css_template and self.ctx:
+            tmpl_ctx = self.get_css_context()
+            css_text = self.ctx.env.render_template(
                 self.css_template,
                 variables=tmpl_ctx,
             )
             req = [resources.CSSText(content=css_text, filename="mknodes_theme.css")]
-        templates = [i for i in self.templates if i]
-        return resources.Resources(css=req, templates=templates)
+        return resources.Resources(css=req)
 
-    def get_template_context(self) -> dict[str, Any]:
+    def get_css_context(self) -> dict[str, Any]:
         """Return variables used to resolve the CSS template.
 
         Can be overridden by subclasses.
@@ -107,6 +108,7 @@ class Theme:
             admonitions=self.admonitions,
             primary_color=self.primary_color,
             text_color=self.text_color,
+            alternating_table_colors=self.alternating_table_colors,
             css_primary_fg=self.text_color,
             css_primary_bg=self.primary_color,
             css_primary_bg_light=self.primary_color,
@@ -117,6 +119,25 @@ class Theme:
             css_default_bg="#DDDDDD",
         )
 
+    @property
+    def context(self):
+        ctx = self.get_css_context()
+        return contexts.ThemeContext(
+            name=self.name,
+            data=self.data,
+            primary_color=self.primary_color,
+            text_color=self.text_color,
+            admonitions=self.admonitions,
+            css_primary_fg=ctx["css_primary_fg"],
+            css_primary_bg=ctx["css_primary_bg"],
+            css_primary_bg_light=ctx["css_primary_bg_light"],
+            css_accent_fg=ctx["css_accent_fg"],
+            css_accent_fg_transparent=ctx["css_accent_fg_transparent"],
+            css_accent_bg=ctx["css_accent_bg"],
+            css_default_fg=ctx["css_default_fg"],
+            css_default_bg=ctx["css_default_bg"],
+        )
+
     @classmethod
     def get_theme(
         cls,
@@ -164,31 +185,24 @@ class Theme:
         """
         return "#333333"
 
-    @property
-    def context(self):
-        ctx = self.get_template_context()
-        return contexts.ThemeContext(
-            name=self.theme_name,
-            data=self.data,
-            primary_color=self.primary_color,
-            text_color=self.text_color,
-            admonitions=self.admonitions,
-            css_primary_fg=ctx["css_primary_fg"],
-            css_primary_bg=ctx["css_primary_bg"],
-            css_primary_bg_light=ctx["css_primary_bg_light"],
-            css_accent_fg=ctx["css_accent_fg"],
-            css_accent_fg_transparent=ctx["css_accent_fg_transparent"],
-            css_accent_bg=ctx["css_accent_bg"],
-            css_default_fg=ctx["css_default_fg"],
-            css_default_bg=ctx["css_default_bg"],
-        )
-
     def adapt_extensions(self, extensions: MutableMapping[str, dict]):
-        pass
+        if self.name.lower() != "mkdocs":
+            return
+        for k in dict(extensions).copy():
+            ext = extensions[k]
+            if k == "pymdownx.highlight":
+                # default style "table" looks broken with mkdocs
+                ext["pymdownx.highlight"]["linenums_style"] = "inline"  # pymdownx-inline
 
     def adapt_extras(self, extras: dict):
         pass
 
+    @property
+    def template_path(self) -> str:
+        from mkdocs import utils
+
+        return utils.get_theme_dir(self.name)
+
 
 if __name__ == "__main__":
     theme = Theme.get_theme("material")
