@@ -5,7 +5,7 @@ import itertools
 import os
 import re
 
-from typing import Any, Literal, TypeVar
+from typing import Any, Literal, ParamSpec, TypeVar
 
 from mknodes.utils import log
 
@@ -13,6 +13,14 @@ from mknodes.utils import log
 logger = log.get_logger(__name__)
 
 
+T = TypeVar("T")
+
+
+def reduce_list(data_set: Iterable[T]) -> list[T]:
+    """Reduce duplicate items in a list and preserve order."""
+    return list(dict.fromkeys(data_set))
+
+
 def get_hash(obj: Any) -> str:
     import hashlib
 
@@ -46,7 +54,7 @@ def extract_header_section(markdown: str, section_name: str) -> str | None:
         return None
     section_level = len(header_match[1])
     start_index = header_match.span()[1] + 1
-    end_pattern = re.compile(f"^#{{2,{section_level}}} ", re.MULTILINE)
+    end_pattern = re.compile(f"^#{{1,{section_level}}} ", re.MULTILINE)
     end_match = end_pattern.search(markdown[start_index:])
     if end_match is None:
         return markdown[start_index:]
@@ -172,36 +180,7 @@ def is_url(path: str) -> bool:
     return path.startswith(("http:/", "https:/", "www."))
 
 
-def relative_url(url_a: str, url_b: str) -> str:
-    """Compute the relative path from URL A to URL B.
-
-    Arguments:
-        url_a: URL A.
-        url_b: URL B.
-
-    Returns:
-        The relative URL to go from A to B.
-    """
-    parts_a = url_a.split("/")
-    if "#" in url_b:
-        url_b, anchor = url_b.split("#", 1)
-    else:
-        anchor = None
-    parts_b = url_b.split("/")
-
-    # remove common left parts
-    while parts_a and parts_b and parts_a[0] == parts_b[0]:
-        parts_a.pop(0)
-        parts_b.pop(0)
-
-    # go up as many times as remaining a parts' depth
-    levels = len(parts_a) - 1
-    parts_relative = [".."] * levels + parts_b
-    relative = "/".join(parts_relative)
-    return f"{relative}#{anchor}" if anchor else relative
-
-
-def get_output_from_call(call: Sequence[str]):
+def get_output_from_call(call: Sequence[str]) -> str | None:
     import subprocess
 
     try:
@@ -211,6 +190,25 @@ def get_output_from_call(call: Sequence[str]):
         return None
 
 
+P = ParamSpec("P")
+R = TypeVar("R")
+
+
+def list_to_tuple(fn: Callable[P, R]) -> Callable[P, R]:
+    """Decorater to convert lists to tuples in the arguments."""
+
+    def wrapper(*args: P.args, **kwargs: P.kwargs) -> R:
+        safe_args = [tuple(item) if isinstance(item, list) else item for item in args]
+        if kwargs:
+            kwargs = {
+                key: tuple(value) if isinstance(value, list) else value
+                for key, value in kwargs.items()
+            }  # type: ignore[assignment]
+        return fn(*safe_args, **kwargs)  # type: ignore[arg-type]
+
+    return wrapper
+
+
 if __name__ == "__main__":
     strings = groupby_first_letter([str(i) for i in range(1000)])
     print(strings)
