@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-import mknodes
+import mknodes as mk
 
 
 EXPECTED = """## Header
@@ -45,30 +45,30 @@ EXPECTED_SORTED = """[^1]:
 
 
 def test_empty():
-    annotation = mknodes.MkFootNotes()
+    annotation = mk.MkFootNotes()
     assert not str(annotation)
 
 
 def test_if_annotations_get_sorted():
-    node = mknodes.MkFootNotes()
+    node = mk.MkFootNotes()
     node[2] = "2"
     node[1] = "1"
     assert str(node) == EXPECTED_SORTED
 
 
 def test_markdown():
-    annotation = mknodes.MkFootNotes(["abcde\nfghi"] * 10, header="Header")
+    annotation = mk.MkFootNotes(["abcde\nfghi"] * 10, header="Header")
     assert str(annotation) == EXPECTED
 
 
 def test_constructors():
-    annotation_1 = mknodes.MkFootNotes(["abc", "def"])
+    annotation_1 = mk.MkFootNotes(["abc", "def"])
     anns = {1: "abc", 2: "def"}
-    annotation_2 = mknodes.MkFootNotes(anns)
+    annotation_2 = mk.MkFootNotes(anns)
     assert str(annotation_1) == str(annotation_2)
 
 
 def test_mapping_interface():
-    ann = mknodes.MkFootNotes()
+    ann = mk.MkFootNotes()
     ann[1] = "test"
     assert str(ann[1]) == "[^1]:\n    test\n"
