@@ -19,9 +19,7 @@ title: Some title
 """
 
 example_metadata = metadata.Metadata(
-    hide_toc=True,
-    hide_nav=False,
-    hide_path=True,
+    hide=["toc", "path"],
     search_boost=2.0,
     exclude_from_search=False,
     icon="material/emoticon-happy",
